@@ -42,6 +42,28 @@ class ZoomClient:
         response = requests.request("GET", url, headers=headers, data=payload)
         return response.json()
 
+    def getUserSettings(self, userID):
+        url = f"{self.baseUrl}/users/{userID}/settings"
+        payload = {}
+        headers = {
+            'Authorization': f'Bearer {self.accessToken}'
+        }
+        response = requests.request("GET", url, headers=headers, data=payload)
+        return response.json()
+
+    def updateUserSettings(self, userID, req):
+        url = f"{self.baseUrl}/users/{userID}/settings"
+        payload = json.dumps(req)
+        headers = {
+            'Authorization': f'Bearer {self.accessToken}',
+            'Content-Type': 'application/json',
+        }
+        response = requests.request("PATCH", url, headers=headers, data=payload)
+        if response.status_code == 200:
+            return response.json()
+        else:
+            return response.text
+
     def getPhoneUser(self, userID):
         url = f"{self.baseUrl}/phone/users/{userID}"
         payload = {}
@@ -93,6 +115,27 @@ class ZoomClient:
         response = requests.request("POST", url, headers=headers, data=payload)
         return response.json()
 
+    def updatePhoneUser(self, userID, req):
+        """
+        Will return None if successful
+        :param userID:
+        :param req:
+        :return:
+        """
+        url = f"{self.baseUrl}/phone/users/{userID}"
+
+        payload = json.dumps(req)
+        headers = {
+            'Authorization': f'Bearer {self.accessToken}',
+            'Content-Type': 'application/json',
+        }
+
+        response = requests.request("PATCH", url, headers=headers, data=payload)
+        if response.status_code == 204:
+            return None
+        else:
+            return response.json()
+
     def updateUserExtension(self, userID, extension):
         url = f"{self.baseUrl}/phone/users/{userID}"
 
@@ -127,5 +170,3 @@ class ZoomClient:
 
         response = requests.request("POST", url, headers=headers, data=payload)
         return response.json()
-
-
